@@ -504,9 +504,9 @@ class EmergePackage(Mapping):
                  'PV': x[PV] or '0',
                  'PF': x[PF],
                  'P': x[P],
-                 'SLOT': x[SLOT] or '0',
-                 'SLOTONLY': (x[SLOT] or '0').partition('/')[0],
-                 'SLOT!': x[SLOT] or '',
+                 'SLOT': (x[SLOT] or '0').strip(),
+                 'SLOTONLY': (x[SLOT] or '0').partition('/')[0].strip(),
+                 'SLOT!': (x[SLOT] or '').strip(),
                  'REPO': x[REPO] or self.default_repo,
                  'CATEGORY/PN': "%s/%s" % (x[CATEGORY], x[PN]),
                  'PR': x[PR] or 'r0'}
